#
# spec file for package engrampa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.26
Name:           engrampa
Version:        1.26.1
Release:        1.1
Summary:        MATE Desktop archive manager
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM engrampa-1.26.1-add-7zip-support.patch -- Add new 7-zip (7zz and 7zzs) project support (commit 6f49d2c7).
Patch0:         engrampa-1.26.1-add-7zip-support.patch
BuildRequires:  caja >= %{_version}
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcaja-extension) >= %{_version}
BuildRequires:  pkgconfig(sm)
Recommends:     %{name}-lang
# Formats that we likely want to support by default.
Recommends:     bzip2
Recommends:     cpio
Recommends:     gzip
Recommends:     rpm
Recommends:     unar
Recommends:     unzip
Recommends:     xz
Recommends:     zip
# Additional formats that are supported.
Suggests:       lhasa
Suggests:       lzip
Suggests:       lzop
Suggests:       rzip
Suggests:       zoo
# FIXME: Formats for which we don't have packages. Some are free software that
# we could package.
#Suggests:       lrzip
#Suggests:       arj
#Suggests:       ncompress
#Suggests:       rar
#Suggests:       unace
#Suggests:       unalz
#Suggests:       unstuff
# mate-file-archiver was last used in openSUSE 13.1.
Provides:       mate-file-archiver = %{version}
Obsoletes:      mate-file-archiver < %{version}
Obsoletes:      mate-file-archiver-lang < %{version}
%glib2_gsettings_schema_requires
%if 0%{?suse_version} > 1500
Recommends:     7zip
%else
Recommends:     p7zip
%endif

%description
Engrampa is an archive manager for the MATE Desktop Environment.
This means that you can create and modify archives; view the
content of an archive; view and modify a file contained in the
archive; extract files from the archive.

%lang_package

%package -n caja-%{name}
Summary:        MATE Desktop engrampa plugin for caja
Requires:       %{name} = %{version}-%{release}
# mate-file-manager-engrampa was last used in openSUSE 13.1.
Provides:       mate-file-manager-%{name} = %{version}
Obsoletes:      mate-file-manager-%{name} < %{version}

%description -n caja-engrampa
Engrampa is an archive manager for the MATE Desktop Environment.
This means that you can create and modify archives; view the
content of an archive; view and modify a file contained in the
archive; extract files from the archive.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static                    \
  --disable-scrollkeeper              \
  --libexecdir=%{_libexecdir}/%{name}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/dbus-1/services/org.mate.Engrampa.service
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/help/C/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_mandir}/man?/%{name}.?%{?ext_man}

%files -n caja-%{name}
%{_datadir}/caja/extensions/libcaja-engrampa.caja-extension
%{_libdir}/caja/extensions-2.0/libcaja-%{name}.so

%files lang -f %{name}.lang

%changelog
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * fr-process: Fix memory leak.
  * Fix archive file save as function.
  * file-data: Fix memory leak.
  * fr-window: Fix memory leak.
  * dlg-package-installer: Fix memory leak.
  * Update translations.
- Add engrampa-1.26.1-add-7zip-support.patch: Add new 7-zip
  (7zz and 7zzs) project support (commit 6f49d2c7).
* Wed Aug 11 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * update copyright to 2021
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.2:
  * Translations update
  * ar: fix filename in file list
  * rar 6.00: fix listing archive content with encrypted file list
  * fr-archive: Fix memory leak
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * Avoid memory leak in java utils.
  * build: Silent build warnings for distcheck.
  * engrampa.appdata.xml: Recursive acronyms for .iso, .rpm
    filetypes.
  * autoconf: Get zstd mime type using libmagic if enabled.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.2):
  * fr-command-rpm: Use rpm2cpio binary shipped with rpm package.
  * Add source rpm to supported mime-types.
  * Use cpio if no binary is found.
  * Add a configure environment variable to select the cpio path.
  * 7z: Don't set the work directory, i.e. use temporary directory.
  * Check if a mime-type is an alias in
    compute_supported_archive_types.
  * Define LOCALEDIR for bindtextdomain().
  * Migrate from intltool to gettext.
  * Clean file type selection in the new archive dialogue.
  * Automatically sets the maximum size of static arrays.
  * Fix localised pause UI logic.
  * dlg-extract: GtkFileChooserDialog instead of set extra widget.
  * dlg-batch-add: Set dialog image from icon-name instead of
    pixbuf.
  * Fix build using the -fno-common flag.
  * fr-process: Do not override LC_CTYPE.
- Drop support for old openSUSE versions.
* Fri Jan  3 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.23.2
  * tx: sync with transifex
  * LHA: add test for checking compressed file integrity
  * Add application/(x-compress|x-rpm|x-lzh-compressed) in local magic
  * Show archive type in properties dialog
  * Zstandard: read .tar.zst files
  * Zstandard: add test for checking compressed file integrity
  * Zstandard: Update MIME type
  * Ar: Update MIME type and add magic numbers
  * fr-command-ar: fetch dates with strptime
  * Remove internal mkdtemp and define feature test macro
  * fr-command-tar: fetch dates with strptime
  * Use mate-compiler-flags.m4 provided by mate-common
  * ar: don't remove leading whitespaces in filename field
  * i18n caja extension copyright
  * LHA: make compatible with content-type response from gio file query
  * fr-command-dpkg: fetch dates with strptime
  * dlg-prop: set property label in ui file
  * Add extract-dialog-options.ui
  * LHA: Fix internet media type
  * Use g_list_free_full and g_slist_free_full
  * dlg-prop: show the exact number of bytes as part of the size
  * dlg-prop: allow to open the archive's folder
  * remove warnings: ‘gtk_image_new_from_stock’ is deprecated
  * glib-utils & gtk-utils: Remove unused functions
  * dlg-package-installer: show icons in error dialog buttons
  * dlg-package-installer: remove warning ‘GtkStock’ is deprecated
  * gio-utils: Remove unused functions
  * glib-utils: Remove get_time_string()
  * unace 2.5: Don't show archive summary in file listing
  * tar: don't remove leading whitespaces in filename field
  * Initialization discards ‘const’ qualifier from pointer target type
  * remove warnings: "ENABLE_MAGIC" is not defined, evaluates to 0
  * comparison of integer expressions of different signedness: ‘size_t’
  * Missing initializer for struct field
  * remove warnings: cast from function call [-Wbad-function-cast]
  * remove build warning: local variable shadows another variable
* Mon Nov  4 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Fix build error complaining about conflicting types for
  g_ptr_array_copy by updating to 1.23.1.
- Update to version 1.23.1:
  * Update translations
  * glib-utils: Remove unused function - g_ptr_array_copy
  * Remove some unused/deprecated functions
  * Various smaller fixes
* Wed Sep 25 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Remove build require on libxml2-python as it's not required. There
  is no sign in the source code that it's needed.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * tx: sync with transifex
  * Remove trailing whitespaces
  * Update FSF address
  * Remove hard-coded 'Back' label button
  * Avoid deprecated g_type_class_add_private
  * Use the Automake variable nobase_dist_icons_DATA
  * Help: replace link linkend with xref linkend
  * file-utils: avoid out of bound memory access
  * actions: avoid use of memory after it is freed
  * fr-process: Fix memory leak: 'g_shell_quote' needs to be freed
  * fr-process: Fix memory leak: 'g_strconcat' needs to be freed
  * [Security] fr-process: avoid 'strcpy' and 'strcat'
  * enable clang analyzer
  * fr-process: Fix memory leak
  * Help: Fix version to 1.22 and update pot file
  * help: update copyright
  * Upgrade the manual to docbook 5.0
  * Support .udeb package format
  * Clean-up archive list and descriptions
  * Show version on command line
- remove patches:
  * engrampa-gtk-3.20.patch: we don't support systems with gtk-3.20
    anymore
- BuildRequire gtk3 >= 3.22
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Help: Replace link linkend with xref linkend.
  * file-utils: Avoid out of bound memory access.
  * actions: Avoid use of memory after it is freed.
  * fr-process: Fix memory leak: "g_shell_quote" needs to be freed.
  * fr-process: Fix memory leak: "g_strconcat" needs to be freed.
  * [Security] fr-process: Avoid "strcpy" and "strcat".
  * fr-process: Fix memory leak.
  * Help: Fix version to 1.22.
  * Help: Update copyright.
  * Upgrade the manual to docbook 5.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Add .a (Ar) support.
  * fr-window: Replace deprecated gtk_menu_popup functions.
  * Fix a crash on exit after using the Open With dialogue.
  * Avoid deprecated GtkStock.
  * Avoid array index out of bounds parsing dpkg-deb --info.
  * warning: Use of memory after it is freed.
  * Read authors (updated) from engrampa.about gresource.
  * eggsmclient: Avoid deprecated 'g_type_class_add_private'.
  * rar/unrar: Fix: "overwrite existing files" disabled must work.
  * fix fr-command-cfile.c: fr_process_set_working_dir.
  * Added test integrity for brotli.
  * Added test integrity for the cfile compressors: gzip, bzip2,
    etc.
  * Move appdata to the metainfo/ directory.
  * fr-window: Show the pause button only if the dialogue is
    working.
  * fr-window: Avoid 'gtk_dialog_add_button' with stock ids.
  * fr-window: Hide the progress bar if the process is paused.
  * fr-window: Change the info label if process is paused/resumed.
  * fr-window: Little improvements in the look of pause/resume
    button.
  * Adding pause and start functions.
  * Fix implementation and use of the alternative package name
    lookup.
  * Add support for brotli (*.tar.br) compressed tar archives.
  * Add brotli support.
  * Add the ability to support 'unar' over .zip archives.
  * Add support for OpenDocument formats.
  * UI: On the properties dialogue, focus the Close button instead
    of the Help button by default.
  * Update translations.
- Rebase engrampa-gtk-3.20.patch.
* Thu Dec 13 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Disable deprecation warnings for distcheck.
  * Use make functions for HELP_LINGUAS.
  * Replace -Dokumentationsprojekt with Documentation Project.
  * Manual: Update file format descriptions using shared-mime-info.
  * Fix url of ulinks to point to mate-user-guide.
  * "UNIX and Linux systems" -> "Linux and UNIX-like systems".
  * fr-window: Fix a typo.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Add .a (Ar) support.
  * Fix crash on exit after using Open With dialogue.
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * UI files: Avoid deprecations.
  * gtk-utils, fr-window: Remove some GtkStock deprecations.
  * gtk-utils: Avoid deprecated gtk_icon_size_lookup_for_settings.
  * fr-window: Avoid deprecated GtkMisc and GtkAlignment.
  * dlg-add-folder: Avoid deprecated gtk_alignment_new().
  * build: Use a variable instead of a hardcoded file name when
    cleaning.
  * Avoid deprecated gdk_screen_make_display_name().
  * Don't use deprecated gtk_show_uri().
  * Avoid deprecated gdk_screen_get_number().
  * Add the button "Show the Files and Quit" in the progress
    dialogue.
  * build: Use PKG_CONFIG to fix cross-building.
  * Add MATE's copyright to the About dialogue and Caja extension.
  * 7z: Fix renaming files with password without the list
    encrypted.
- Add engrampa-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
- Recommend the same format packages as file-roller does.
* Tue Nov  7 2017 sor.alexei@meowr.ru
- Update to version 1.18.3 (changes since 1.18.1):
  * Fix browsing history.
  * Hide directories in "View All Files"
  * Fix: Wrong behaviour of Skip button in Replace file dialogue.
  * 7z: Fix delete/rename files/directories with the list encrypted.
  * Fix creating zip files in "maximum" compression level.
  * Update translations.
* Wed Apr  5 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Add a style class frame to scrolledwindows.
  * Add a style class engrampa-window.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * Update engrampa NEWS to use consistent, project wide, markdown-like
    formatting.
  * Build: Require Caja >= 1.17.1 to build against the GTK+3 version
    of libcaja-extension.
  * tar: Add support for pixz for .tar.xz files.
  * tar: Add support for lbzip2 on .tar.bz2 files.
  * lha: Add support for Amiga files.
  * Some corrections in the GSettings schema.
  * check the rar/unrar version to work the new date style with all versions
  * Fix: rar file listing now shows correct date with recent binary.
  * Fix: Open the 7z first split volume after compress.
  * Fix: Compress rar and 7z split into volumes.
  * build: Remove an option that disables deprecated stuff.
  * zip: Add ear and war to the supported types list.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Move to GTK+3 (require GTK+ >= 3.14), drop GTK+2 code and
  - -with-gtk build option.
  * Port to GtkApplication.
  * Use natural sort order when sorting by filename.
  * Use application chooser dialog from GTK+ for "Open With"
    command instead of custom code.
  * Make "encrypt header" option insensitive if no password is
    specified.
  * Give unrar priority over p7zip when processing RAR archives.
  * 7z: Add support for p7zip-rar >= 15.14.
  * 7z: Fix issues with files prefixed with '@'.
  * Fix some GTK+ deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * tar: Fix problems with backslashes.
  * 'All files' is duplicated in available formats.
  * Fix extracting files with single-character names.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to version 1.13.1 (changes since 1.12.0):
  * 7z: Correct checking for p7zip 15.09+.
  * Drop MateConf migration script.
  * Fix random crash in "open with" dialog.
  * rar: Avoid "No files to extract" message when disabling
    overwriting existing files.
  * tar: Allow changing contents of .txz files (like it's allowed
    for .tar.xz files)
  * unar, 7z: Avoid problems with '?' char in filenames.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Fix ngettext usage in progress dialog.
  * Make extracting multiple archives to a separate dir actually
    work.
  * Fix overwrite check when the files to be extracted are inside a
    directory.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Some string fixes.
  * Update translations.
* Thu Oct  1 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Do not crash while opening archives on network drives.
  * Fix extracting archives with '[' in filename.
  * Some other improvements.
* Mon Jul 13 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Help fixes.
  * UI fixes.
* Tue May  5 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.2):
  * Update translations.
- Spec cleanup.
* Thu Jan 22 2015 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  * Fix hyphen-as-minus-sign issues for engrampa.1 man page
  * Add keywords key to .desktop file
* Wed Dec 10 2014 p.drouand@gmail.com
- Add caja make requirement; do not own extensions directory
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + Fix open rar file inside a rar file
  + Drop support for Gtk+ < 2.24
  + Unifiy code as to be used in Gtk+2 and Gtk+3
  + Drop support for Glib < 2.32
  + Do not set the selected app as the system default
  + Fix possible errors with some password protected files
  + Use Caja GSettings schema optionally
  + Add ini file for caja extension
  + Add engrampa.appdata.xml
  + Fix memory leaks
  + Fixed crash when clicking Cancel in Add Files
  + use g_get_user_config_dir instead of using .config/mate
  + do not set the "last output" dialog as modal to allow the user to resize it
  + Fixed loading of multi-volume rar archives with 7zip
  + use GtkRecentAction objects to create the recent file choosers
  + Several string improvements
  + set a mnemonic for the label in the request dialog
  + Change strings to use ellipsis
  + allow to compress iso images and tar archives from the caja menu
  + Ask overwrite confirmation when extracting files with drag&drop
  + Small fixes for Gtk3 engrampa
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Fix hyphen-as-minus-sign issues for engrampa.1 man page
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Several small fixes to manpages
  + Add keywords key to .desktop file
  + Fix opening file from rar file (unrar)
  + Do not set the selected app as the system default
  + Fix possible errors with some password protected files (RAR 5)
* Wed Mar 12 2014 p.drouand@gmail.com
- Obsolete mate-file-archiver-lang in main package to avoid conflicts
  with this one
- Require libcaja-extension to ensure building with correct version
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + updates to man pages.
  + update translations.
* Fri Feb 14 2014 p.drouand@gmail.com
- Initial release (version 1.7.1)
